Module metadata

Module metadata 

Extra metadata attached to leaf nodes to encode a CST

Structs

Metadata
Metadata for a given syntax token.
Span
A representation of a unique location in a source file

Enums

NonTriviaToken
A non-trivia token from the source file
SpanRelation
A relationship between two Spans, ordering them relative to each other in declaration order

Type Aliases

ByteSpan
The start and end bytes of a particular portion of a source file